@@ -13,7 +13,7 @@ my $arg = join('',@ARGV);
 $mali = 1 if ($arg =~ /mali/i); # Mali GPU correction mode
 $file = 1 if ($arg =~ /file/i); # File Handle drawing mode
 
-my $F = Graphics::Framebuffer->new('MALI' => $mali, 'FB_DEVICE' => '/dev/fb0','FILE_MODE' => $file,'SHOW_ERRORS' => 0);
+my $F = Graphics::Framebuffer->new('MALI' => $mali, 'FB_DEVICE' => '/dev/fb0','FILE_MODE' => $file,'SHOW_ERRORS' => 0,'LINE_PADDING'=> 0);
 
 $SIG{'QUIT'} = sub { $F->cls('ON'); exit(0); };
 $SIG{'INT'}  = sub { $F->cls('ON'); exit(0); };
@@ -94,21 +94,21 @@ sleep $wait;
 print_it($F,'Rounded Box Test');
 foreach my $p (1..(50 * $factor)) {
     $F->set_color({'red' => rand(256),'green' => rand(256),'blue' => rand(256)});
-    $F->box({'x' => rand($XX),'y' => rand($YY),'xx' => rand($XX),'yy' => rand($YY),'radius' => rand(20)+1});
+    $F->box({'x' => rand($XX),'y' => rand($YY),'xx' => rand($XX),'yy' => rand($YY),'radius' => rand(20)+3});
 }
 sleep $wait;
 
 print_it($F,'Filled Rounded Box Test');
 foreach my $p (1..(50 * $factor)) {
     $F->set_color({'red' => rand(256),'green' => rand(256),'blue' => rand(256)});
-    $F->box({'x' => rand($XX),'y' => rand($YY),'xx' => rand($XX),'yy' => rand($YY),'radius' => rand(80)+1,'filled' => 1});
+    $F->box({'x' => rand($XX),'y' => rand($YY),'xx' => rand($XX),'yy' => rand($YY),'radius' => rand(80)+3,'filled' => 1});
 }
 sleep $wait;
 
 print_it($F,'Gradient Rounded Box Test');
 foreach my $p (1..(50 * $factor)) {
     $F->set_color({'red' => rand(256),'green' => rand(256),'blue' => rand(256)});
-    $F->box({'x' => rand($XX),'y' => rand($YY),'xx' => rand($XX),'yy' => rand($YY),'radius' => rand(80)+1,'filled' => 1,
+    $F->box({'x' => rand($XX),'y' => rand($YY),'xx' => rand($XX),'yy' => rand($YY),'radius' => rand(80)+3,'filled' => 1,
                 'gradient' => {
                     'start' => {
                         'red'   => rand(256),
@@ -231,23 +231,27 @@ foreach my $p (1..(20 * $factor)) {
 }
 sleep $wait;
 
-print_it($F,'Testing Cubic Bezier Curves');
+print_it($F,'Testing Bezier Curves');
 
 foreach my $z (1..(50 * $factor)) {
     $F->set_color({'red' => rand(256),'green' => rand(256),'blue' => rand(256)});
-    $F->cubic_bezier({'coordinates' => [rand($XX),rand($YY),rand($XX),rand($YY),rand($XX),rand($YY),rand($XX),rand($YY)]});
+    my @coords = ();
+    foreach my $r (1..int(rand(20))) {
+        push(@coords,int(rand($XX)),int(rand($YY)));
+    }
+    $F->bezier({'coordinates' => \@coords, 'points' => 100});
 }
 sleep $wait;
 
 print_it($F,'Testing TrueType Font Rendering');
 
 for(my $c = 8;$c < 600;$c += (20 * $factor)) {
-    my $x = int(rand(600));
-    my $y = int(rand(900));
-    my $h = int(rand(300)) + 8;
+    my $x  = int(rand(600));
+    my $y  = int(rand(900));
+    my $h  = int(rand(300)) + 8;
     my $ws = rand(4);
 
-    my $b = $F->ttf_print(
+    my $b  = $F->ttf_print(
         {
             'x'            => $x,
             'y'            => $y,
@@ -267,9 +271,11 @@ sleep $wait;
 
 print_it($F,'Testing flood fill');
 $F->set_color({'red' => rand(256),'green' => rand(256),'blue' => rand(256)});
-$F->polygon({'coordinates' => [220,190,$XX-400,40,$center_x+200,$YY,$center_x,$center_y,$center_x-200,$YY]});
+$F->polygon({'coordinates' => [220,190,$XX - 400,90,$center_x + 200,$YY,$center_x,$center_y,$center_x - 200,$YY]});
 $F->set_color({'red' => rand(256),'green' => rand(256),'blue' => rand(256)});
-$F->polygon({'coordinates' => [$center_x+310,$center_y+30, $center_x+10,180, 600,500]});
+$F->polygon({'coordinates' => [$center_x + 310,$center_y + 30, $center_x + 10,180, 600,500]});
+$F->set_color({'red' => rand(256),'green' => rand(256),'blue' => rand(256)});
+$F->circle({'x' => 500,'y' => 320, 'radius' => 100,'pixel_size' => 3});
 
 $F->set_color({'red' => rand(256),'green' => rand(256),'blue' => rand(256)});
 $F->fill({'x' => $center_x+100, 'y' => $center_y + 100});
@@ -286,9 +292,9 @@ $F->splash();
 
 $F->replace_color(
     {
-        'old_red'   => 0,
+        'old_red'   => 128,
         'old_green' => 0,
-        'old_blue'  => 64,
+        'old_blue'  => 0,
         'new_red'   => 0,
         'new_green' => 255,
         'new_blue'  => 255
@@ -303,10 +309,10 @@ $F->splash();
 
 $F->clip_reset();
 
-my $r = 0;
+my $r = 128;
 my $g = 0;
-my $b = 64;
-foreach my $re (1..(25 * $factor)) {
+my $b = 0;
+foreach my $re (1..(5 * $factor)) {
     my $R = int(rand(256));
     my $G = int(rand(256));
     my $B = int(rand(256));
