@@ -43,9 +43,10 @@ cls;
 print STDERR setscroll(1,$Threads); # prevents Perl errors from flooding the screen
 $SIG{'QUIT'} = \&finish;
 $SIG{'INT'}  = \&finish;
+my @thrd;
 foreach my $page (1..$Threads) {
     $waiting[$page] = 0;
-    threads->create(
+    $thrd[$page] = threads->create(
         sub {
             my $Page = shift;
             my $top  = shift;
@@ -73,7 +74,7 @@ while(1) {
     sleep 30;
     $hold = 1;
     foreach my $page (1..$Threads) {
-        while($waiting[$page]) {
+        while($waiting[$page] && $thrd[$page]->is_running()) {
             sleep 1;
         }
     }
